// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

using System.Runtime.InteropServices;

internal static partial class Interop
{
    internal static partial class Kernel32
    {
        [LibraryImport(Libraries.Kernel32)]
        internal static unsafe partial int MultiByteToWideChar(
            uint CodePage, uint dwFlags,
            byte* lpMultiByteStr, int cbMultiByte,
            char* lpWideCharStr, int cchWideChar);

        internal const uint MB_PRECOMPOSED = 0x00000001;
    }
}
